<?php
/*
# ---------------------------------------------------------------------------------------------------------------------
#
# Plugin:		Matchsettings (clickable) for xAseco 1.16+ 
# Description:	Allows to load different matchsettings via click (only available for master admins)
#
# ---------------------------------------------------------------------------------------------------------------------
#
# Author (TM2):	doe-eye "aca" (c) 2014 - https://github.com/doe-eye/loadmaplist
# Update:		Release for xAseco1.16x (c) by L3cKy 20.02.2020
# Version:		1.1
#
# Dependies:	None
# Config:		The plugin don't need any configurations.
#
# ---------------------------------------------------------------------------------------------------------------------
#
# LICENSE: This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ---------------------------------------------------------------------------------------------------------------------
#
# Usage:		Chat command "/ms"
#
# ---------------------------------------------------------------------------------------------------------------------
*/

Aseco::registerEvent('onStartup', 'check_ms');
//handle id's 50000-50100
Aseco::registerEvent('onPlayerManialinkPageAnswer', 'event_ms');
Aseco::addChatCommand('ms', 'clickable matchsettings /ms');

//mark the default matchsettings from config.xml
function check_ms ($aseco) {
global $checkfile, $default_msfile;
	$default_msfile = $aseco->settings['default_tracklist'];
	$checkfile = $default_msfile;
}

//chat ms
function chat_ms($aseco, $command) {
global $checkfile, $default_msfile;

	$player = $command['author'];
	$login = $player->login;

	if (!$aseco->isMasterAdmin($player)) {
		$aseco->client->query('ChatSendServerMessageToLogin', $aseco->formatColors('$z$s$ff0MatchSettings: $f00You need to be an master admin to do that!'), $login);
		return;
	}

	if ($aseco->server->getGame() == 'TMF' && !$aseco->settings['clickable_lists']) {
		$header = '$z$s$fffMatchsettings: $f00Error$fff!';
		$data[] = array('$z$s$fffMatchSettings plugin is temporary $f00offline$fff!');
		$data[] = array('$z$s$fffSet $ff0<clickable_list> $fffto "$0c0True$fff" in $ff0xaseco/config.xml$fff to enable the plugin.');
		display_manialink($login, $header, array('Icons64x64_1', 'TrackInfo', -0.01), $data, array(0.9), 'OK');
		return;
	}

	//get matchsettings folder
	$dir = $aseco->server->trackdir . 'MatchSettings/';
	//search for all .txt files inside matchsettings folder
	$result = glob($dir . '*.txt');
	$player->mlist = array();

	if ($aseco->server->getGame() == 'TMF') {
		$head = 'Available Matchsettings $n$f00(click to load)';
		$msg = array();
		$msg[] = array('#', 'File', 'Status');
		$pid = 1;
		$lines = 0;
		$player->msgs = array();
		$player->msgs[0] = array(1, $head, array(1.4, 0.1, 0.975, 0.525), array('Icons128x128_1', 'Browse'));

		foreach ($result as $value) {
			$ply = basename($value);

			//hide autosave.txt
			if ($ply != 'autosave.txt') {
				$mlist = array();
				$mlist['Name'] = $ply;
				$player->mlist[] = $mlist;

				//clickable list
				if ($pid <= 100) {
					if ($ply != $checkfile) {
						if ($default_msfile == $ply) {
							$ply = ''.$ply.' $n$ff0(default)';
						}
						$status = '';
						$ply = array($ply, $pid+50000);  // action id
						$msg[] = array(str_pad($pid, 2, '0', STR_PAD_LEFT) . '.', $ply, $status);
					} else {
						if ($default_msfile == $ply) {
							$ply = ''.$ply.' $n$ff0(default)';
						}
						$status = '$n$f00Currently Loaded';
						$ply = array('$333'.$ply.'');
						$msg[] = array(str_pad($pid, 2, '0', STR_PAD_LEFT) . '.', $ply, $status);
					}
					$pid++;
					if (++$lines > 17) {
						$player->msgs[] = $msg;
						$lines = 0;
						$msg = array();
						$msg[] = array('#', 'File', 'Status');
					}
				}
			}
		}
		if (count($msg) > 1) { $player->msgs[] = $msg; }
		if (count($player->msgs) > 1) {
			display_manialink_multi($player);
		} else {
			$aseco->client->query('ChatSendServerMessageToLogin', $aseco->formatColors('$z$s$ff0MatchSettings: $f00No matchsetting(s) found!'), $login);
			return;
		}
	} else {
		$aseco->client->query('ChatSendServerMessageToLogin', $aseco->formatColors('$z$s$ff0MatchSettings: $f00This is not a TMNF Server!'), $login);
		return;
	}
}

function event_ms($aseco, $answer) {
global $checkfile;

	$player = $aseco->server->players->getPlayer($answer[1]);
	$login = $player->login;

	if ($answer[2] >= 50001 && $answer[2] <= 50100) {
		$action = $player->mlist[$answer[2]-50001]['Name'];
		if (file_exists($aseco->server->trackdir . 'MatchSettings/' . $action)) {
		$rtn = $aseco->client->query('LoadMatchSettings', 'MatchSettings/' . $action);
			if(!$rtn) {
				trigger_error('[' . $aseco->client->getErrorCode() . '] ' . $aseco->client->getErrorMessage(), E_USER_WARNING);
				$aseco->console($aseco->client->getErrorMessage());
				$aseco->client->query('ChatSendServerMessageToLogin', $aseco->client->getErrorMessage(), $login);
			} else {
				$aseco->console('MatchSettings: '.$action.' loaded by '.$login.'');
				$aseco->client->query('ChatSendServerMessage', $aseco->formatColors('$z$s$ff0MatchSettings: $f00'.$action.' $fffloaded by '.$player->nickname.''));
				$aseco->releaseEvent('onTracklistChanged', array('read', null));
				$checkfile = $action;
				$aseco->settings['default_tracklist'] = $action;
			}
		} else {
			$message = '$z$s$ff0MatchSettings: $i$f00Cannot find ' . $action . '$fff!';
		}
		mainwindow_off($aseco, $player->login);
	}
}
?>
